meeg\_utils.preprocessing.line\_noise
=====================================

.. automodule:: meeg_utils.preprocessing.line_noise


   .. rubric:: Functions

   .. autosummary::

      remove_line_noise_eeg
      remove_line_noise_meg
